==> chanjet-navigator-0.0.9.tgz: package/src/page/NavigateBar.js <==
/**
 * Created with WebStorm.
 * User: gp
 * Date: 16-2-2
 *
 */

import React, { Component } from 'react';
//import immutable from 'immutable'
import clone from 'clone';
import deepmerge from 'deepmerge';
import WebNavBar from './WebDevNavBar'
import NativeNavBar from './NativeNavBar';
import WeixinNavBar from './WeixinNavBar';

/**
 * NavBar 目前支持三种模式： webDevelop, native, 以微信为代表的嵌入式
 * webDevelop 目前不可配置，提供左侧返回按钮，中间标题，待需求和标准制定后添加可配置功能
 * native 只提供json配置，ui不作处理， 具体配置和功能待标准制定后添加 ,跳转时通知native改变导航栏
 * winxin 不提供ui，不提供配置。 目前只对页面标题功能作支持  ,控制右侧是否显示   ,isHide控制不了
 */
class NavigateBar extends Component {

    constructor(props, context){
        super(props, context);
        this.navOpt = props.config.navOpt;
        this.env = props.env;
    }

    render() {

        const {config, env} = this.props;
        let {scope} = config;
        let navOpt = this.navOpt;

        if(env == 'chanjet'){
            return (<NativeNavBar ref="bar" navOpt={navOpt} scope={scope}/>)
        }else if(~['weixin','dingding'].indexOf(env)){
            return <WeixinNavBar ref="bar" {...config} />
        }else{
            return (<WebNavBar ref="bar" {...navOpt} scope={scope} />)
        }

    }

    componentDidMount(){
        let scope = this.props.config.scope;
        scope.setNavbarInstance(this);
    }

    /**
     * 重新设置标题
     * @param title
     */
    setTitle(title){
        this.updateProps({title:title})
    }

    /**
     * 重新设置menu配置, 会重新更新menu展现和行为
     * @param menuCfg {JSONObject} menu配置, 只是item的配置
     */
    setRightMenu(menuCfg) {
        if(this.navOpt.right&&this.navOpt.right.type ==='button'){
            throw new Error('右侧组件不能将一个按钮更改成菜单');
        }
        if(this.navOpt.right){this.navOpt.right.item = []}
        this.updateProps({right:{item:menuCfg}})
    }

    /**
     * 重新设置右侧按钮配置, 会重新更新右侧按钮展现和行为
     * @param rightBtnCfg
     */
    setRightButton(rightBtnCfg) {
        if(this.navOpt.right&&this.navOpt.right.type ==='menu'){
            throw new Error('右侧组件不能将一个菜单更改成按钮');
        }
        this.updateProps({right:{item:rightBtnCfg}});
    }

    showRight(){
        this.updateProps({right:{hide:false}});
    }

    hideRight(){
        this.updateProps({right:{hide:true}});
    }


    updateProps(navBarCfg){
        //this.navOpt = immutable.fromJS(this.navOpt).mergeDeep(navBarCfg).toJS();
        this.navOpt = deepmerge(clone(this.navOpt),navBarCfg);
        this.setState({___dc:new Date().getTime()});
        this.noticeNative(this.navOpt);
    }

    active(){
       this.noticeNative();
    }

    noticeNative(opt){
        var env = this.env;
        if(this.env === 'chanjet'){
            this.refs.bar.noticeNative();
        }else if(env === 'weixin'){
            this.refs.bar.noticeWeixin(opt);
        }
    }

    executeNativeClick(uri){
        document.activeElement.blur();
        var scope = this.props.config.scope;
        if(!uri)return;
        let arr = uri.split('/');
        let len = arr.length;
        let navBar = this.navOpt;
        let i = len;

        let onClick = navBar;
        while(i>0){
            onClick = onClick[arr[len-i]];
            i--;
        }
        onClick.apply(scope);
    }
    
    back(){
        this.ref.bar.back();
    }



}

export default NavigateBar;

==> chanjet-navigator-2.1.1.tgz: package/src/page/NavigateBar.js <==
/**
 * Created with WebStorm.
 * User: gp
 * Date: 16-2-2
 *
 */

import React, { Component } from 'react';
//import immutable from 'immutable'
import clone from 'clone';
import deepmerge from 'deepmerge';
import WebNavBar from './WebDevNavBar'
import NativeNavBar from './NativeNavBar';
import WeixinNavBar from './WeixinNavBar';

/**
 * NavBar 目前支持三种模式： webDevelop, native, 以微信为代表的嵌入式
 * webDevelop 目前不可配置，提供左侧返回按钮，中间标题，待需求和标准制定后添加可配置功能
 * native 只提供json配置，ui不作处理， 具体配置和功能待标准制定后添加 ,跳转时通知native改变导航栏
 * winxin 不提供ui，不提供配置。 目前只对页面标题功能作支持  ,控制右侧是否显示   ,isHide控制不了
 */
class NavigateBar extends Component {

    constructor(props, context){
        super(props, context);
        this.navOpt = props.config.navOpt;
        this.env = props.env;
    }

    render() {

        const {config, env} = this.props;
        let {scope} = config;
        let navOpt = this.navOpt;

        if(env == 'chanjet'){
            return (<NativeNavBar ref="bar" navOpt={navOpt} scope={scope}/>)
        }else if(~['weixin','dingding'].indexOf(env)){
            return <WeixinNavBar ref="bar" {...config} />
        }else{
            return (<WebNavBar ref="bar" {...navOpt} scope={scope} />)
        }

    }

    componentDidMount(){
        let scope = this.props.config.scope;
        scope.setNavbarInstance(this);
    }

    /**
     * 重新设置标题
     * @param title
     */
    setTitle(title, cb){
        this.updateProps({title:title}, cb)
    }

    /**
     * 重新设置menu配置, 会重新更新menu展现和行为
     * @param menuCfg {JSONObject} menu配置, 只是item的配置
     */
    setRightMenu(menuCfg, cb) {
        if(this.navOpt.right&&this.navOpt.right.type ==='button'){
            throw new Error('右侧组件不能将一个按钮更改成菜单');
        }
        if(this.navOpt.right){this.navOpt.right.item = []}
        this.updateProps({right:{item:menuCfg}})
    }

    /**
     * 重新设置右侧按钮配置, 会重新更新右侧按钮展现和行为
     * @param rightBtnCfg
     */
    setRightButton(rightBtnCfg, cb) {
        if(this.navOpt.right&&this.navOpt.right.type ==='menu'){
            throw new Error('右侧组件不能将一个菜单更改成按钮');
        }
        this.updateProps({right:{item:rightBtnCfg}});
    }

    /**
     * 显示右侧按钮或菜单
     */
    showRight(cb){
        this.updateProps({right:{hide:false}},cb);
    }

    /**
     * 隐藏右侧按钮或菜单
     */
    hideRight(cb){
        this.updateProps({right:{hide:true}, cb});
    }

    /**
     * 启用右侧区域事件交互
     * @param cb
     */
    enableRightUserInteraction(cb){
        this.updateProps({right:{userInteraction:true}, cb});
    }

    /**
     * 停用右侧区域事件交互
     * @param cb
     */
    disableRightUserInteraction(cb){
        this.updateProps({right:{userInteraction:false}, cb});
    }

    updateProps(navBarCfg, cb){
        //this.navOpt = immutable.fromJS(this.navOpt).mergeDeep(navBarCfg).toJS();
        this.navOpt = deepmerge(clone(this.navOpt),navBarCfg);
        this.setState({___dc:new Date().getTime()});
        this.noticeNative(this.navOpt, cb);
    }

    active(){
       this.noticeNative();
    }

    noticeNative(opt,cb){
        var env = this.env;
        if(this.env === 'chanjet'){
            this.refs.bar.noticeNative(cb);
        }else if(env === 'weixin'){
            this.refs.bar.noticeWeixin(opt);
        }
    }

    executeNativeClick(uri){
        document.activeElement.blur();
        var scope = this.props.config.scope;
        if(!uri)return;
        let arr = uri.split('/');
        let len = arr.length;
        let navBar = this.navOpt;
        let i = len;

        let onClick = navBar;
        while(i>0){
            onClick = onClick[arr[len-i]];
            i--;
        }
        onClick.apply(scope);
    }
    
    back(){
        this.refs.bar.back();
    }



}

export default NavigateBar;
